@@ -9,11 +9,17 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 from .analysis_data import AnalysisData
-from .ap_info import SampleCollection, fetch_ap_info, load_ap_info_from_single_file
+from .ap_info import (
+    SampleCollection,
+    cache_ap_info,
+    fetch_ap_info,
+    load_ap_info_from_single_file,
+)
 
 __all__ = [
     "AnalysisData",
     "fetch_ap_info",
     "load_ap_info_from_single_file",
     "SampleCollection",
+    "cache_ap_info",
 ]
