@@ -12,6 +12,7 @@
 import itertools
 import logging
 import os
+from collections import defaultdict
 
 from apd.ap_info import (
     SampleCollection,
@@ -28,7 +29,7 @@ def _validate_tags(tags, default_tags=None):
     """Method that checks the dictionary of tag names, values that should be used
     to filter the data accordingly.
 
-     - Special cases ate handled: tags "name" and "version" as well as "data" and "mc"
+     - Special cases are handled: tags "name" and "version" as well as "data" and "mc"
         (which are converted to a "config" value).
      - tag values cannot be None
      - tag values cannot be of type bytes
@@ -176,6 +177,7 @@ class AnalysisData:
         analysis,
         metadata_cache=None,
         api_url="https://lbap.app.cern.ch",
+        ap_date=None,
         **kwargs,
     ):
 
@@ -196,10 +198,24 @@ class AnalysisData:
                 self.samples = metadata_cache
             else:
                 logger.debug("Using metadata cache %s", metadata_cache)
-                self.samples = load_ap_info(metadata_cache, working_group, analysis)
+                try:
+                    self.samples = load_ap_info(
+                        metadata_cache, working_group, analysis, ap_date=ap_date
+                    )
+                except FileNotFoundError:
+                    self.samples = fetch_ap_info(
+                        working_group, analysis, None, api_url, ap_date=ap_date
+                    )
         else:
             logger.debug("Fetching Analysis Production data from %s", api_url)
-            self.samples = fetch_ap_info(working_group, analysis, None, api_url)
+            self.samples = fetch_ap_info(
+                working_group, analysis, None, api_url, ap_date=ap_date
+            )
+
+        self.available_tags = defaultdict(set)
+        for sample in self.samples:
+            for k, v in self.samples._sampleTags(sample).items():
+                self.available_tags[k].add(v)
 
     def __call__(
         self, *, version=None, name=None, return_pfns=True, check_data=True, **tags
@@ -215,7 +231,7 @@ class AnalysisData:
         if iterable(version):
             raise Exception("version argument doesn't support iterables")
 
-        # Establishing the list of damples to run on
+        # Establishing the list of samples to run on
         samples = self.samples
 
         if name:
@@ -247,7 +263,7 @@ class AnalysisData:
             for tagname, tagvalue in effective_tags.items():
                 logger.debug("Filtering for %s = %s", tagname, tagvalue)
 
-            # Appying the filters in one go
+            # Applying the filters in one go
             samples = samples.filter(**effective_tags)
             logger.debug("Matched %d samples", len(samples))
 
@@ -278,6 +294,27 @@ class AnalysisData:
         return samples
 
     def __str__(self):
-        txt = f"AnalysysProductions: {self.working_group} / {self.analysis}\n"
+        txt = f"AnalysisProductions: {self.working_group} / {self.analysis}\n"
         txt += str(self.samples)
         return txt
+
+    def summary(self, tags: list = None) -> dict:
+        summary = {}
+        if tags:
+            for tag in tags:
+                if tag in self.available_tags:
+                    try:
+                        values = sorted(self.available_tags[tag])
+                    except TypeError as exc:
+                        raise ValueError(
+                            f"Could not sort the values for tag ({tag}). Please check that the values are sensible.\n"
+                        ) from exc
+                    values = list(self.available_tags[tag])
+                    summary[tag] = values
+                else:
+                    raise ValueError(
+                        f"Requested tag ({tag}) not valid for the given production (wg: {self.working_group}, analysis: {self.analysis})!"
+                    )
+        else:
+            summary = self.available_tags
+        return summary
