@@ -10,7 +10,6 @@
 ###############################################################################
 import pytest
 
-import apd.cern_sso
 from apd import AnalysisData
 from apd.analysis_data import sample_check
 
@@ -22,11 +21,7 @@ def test_fromcache(apinfo_cache):
     assert len(datasets(datatype=["2012", "2016"], polarity="magdown")) == 12
 
 
-def test_fromendpoint(monkeypatch, mocked_responses):
-    def patched_get_sso_token(uri, app, a, b, c):
-        return ""
-
-    monkeypatch.setattr(apd.cern_sso, "get_sso_token", patched_get_sso_token)
+def test_fromendpoint(monkeypatch, mocked_responses, patched_get_api_token):
     monkeypatch.setenv("APD_METADATA_CACHE_DIR", "")
     datasets = AnalysisData("SL", "RDs")
     assert len(datasets(datatype="2012", polarity=["magup", "magdown"])) == 11
@@ -85,3 +80,10 @@ def test_sample_check_load_dataset_error(apinfo_multipleversions):
             polarity="magup",
         )
         datasets()
+
+
+def test_summary(apinfo_multipleversions):
+    datasets = AnalysisData("SL", "RDs", metadata_cache=apinfo_multipleversions)
+    tagname = "datatype"
+    dt = set(datasets.summary([tagname])[tagname])
+    assert dt == set(["2011", "2018", "2016", "2017", "2012"])
