@@ -12,6 +12,7 @@
 #
 #
 
+import datetime
 import json
 import os
 from pathlib import Path
@@ -19,7 +20,6 @@ from pathlib import Path
 import pytest
 import responses
 
-import apd
 from apd.ap_info import (
     cache_ap_info,
     fetch_ap_info,
@@ -33,7 +33,7 @@ APINFO_PATHS = DATA_DIR / "rds_ap_info.json"
 
 @pytest.fixture
 def apinfo():
-    """ load the requests test data  """
+    """load the requests test data"""
     return load_ap_info_from_single_file(APINFO_PATHS)
 
 
@@ -63,16 +63,13 @@ def mocked_responses():
 
 
 @pytest.fixture
-def apinfo_cache(tmp_path, mocked_responses, monkeypatch):
-    """ load the requests test data and cache it in a temp dir  """
-
-    def patched_get_sso_token(uri, app, a, b, c):
-        return ""
-
-    monkeypatch.setattr(apd.cern_sso, "get_sso_token", patched_get_sso_token)
+def apinfo_cache(tmp_path, mocked_responses, patched_get_api_token):
+    """load the requests test data and cache it in a temp dir"""
+    ap_date = datetime.datetime(2021, 12, 1, 9, 0, 0).isoformat()
     cachedir = tmp_path / "cache"
     os.makedirs(cachedir)
     cache_ap_info(cachedir, "SL", "RDs")
+    cache_ap_info(cachedir, "SL", "RDs", ap_date=ap_date)
     return cachedir
 
 
@@ -81,27 +78,30 @@ def test_load_from_cache(apinfo_cache):
     assert len(pi.PFNs()) == 58
 
 
+def test_load_from_cache_withdate(apinfo_cache):
+    ap_date = datetime.datetime(2021, 12, 1, 9, 0, 0).isoformat()
+    pi = load_ap_info(apinfo_cache, "SL", "RDs", ap_date)
+    assert len(pi.PFNs()) == 58
+
+
 def test_load_single_file():
     pi = load_ap_info_from_single_file(APINFO_PATHS)
     assert len(pi.PFNs()) == 58
 
 
-def test_fetch(monkeypatch, mocked_responses):
-    def patched_get_sso_token(uri, app, a, b, c):
-        return ""
-
-    monkeypatch.setattr(apd.cern_sso, "get_sso_token", patched_get_sso_token)
-
+def test_fetch(mocked_responses, patched_get_api_token):
     pi = fetch_ap_info("SL", "RDs")
     assert len(pi.PFNs()) == 58
 
 
-def test_cache(monkeypatch, mocked_responses, tmp_path):
-    def patched_get_sso_token(uri, app, a, b, c):
-        return ""
+def test_fetch_withdate(mocked_responses, patched_get_api_token):
+    ap_date = datetime.datetime(2021, 12, 1, 9, 0, 0).isoformat()
 
-    monkeypatch.setattr(apd.cern_sso, "get_sso_token", patched_get_sso_token)
+    pi = fetch_ap_info("SL", "RDs", ap_date=ap_date)
+    assert len(pi.PFNs()) == 58
 
+
+def test_cache(mocked_responses, tmp_path, patched_get_api_token):
     cachedir = tmp_path / "cache"
     os.makedirs(cachedir)
     pi = cache_ap_info(cachedir, "SL", "RDs")
@@ -111,6 +111,18 @@ def test_cache(monkeypatch, mocked_responses, tmp_path):
     assert os.path.exists(cachedir / "SL" / "RDs" / "tags.json")
 
 
+def test_cache_withdate(mocked_responses, tmp_path, patched_get_api_token):
+    ap_date = datetime.datetime(2021, 12, 1, 9, 0, 0).isoformat()
+
+    cachedir = tmp_path / "cache"
+    os.makedirs(cachedir)
+    pi = cache_ap_info(cachedir, "SL", "RDs", ap_date=ap_date)
+    assert len(pi.PFNs()) == 58
+    assert os.path.exists(cachedir / "archives" / ap_date / "SL")
+    assert os.path.exists(cachedir / "archives" / ap_date / "SL" / "RDs.json")
+    assert os.path.exists(cachedir / "archives" / ap_date / "SL" / "RDs" / "tags.json")
+
+
 def test_filter_samples(apinfo):
     pi = apinfo.filter("datatype", "2012")
     assert len(pi.PFNs()) == 11
